@@ -3,10 +3,11 @@
 from .base import MetricUnit
 from .exceptions import MetricUnitError, MetricValueError, SchemaValidationError
 from .metric import single_metric
-from .metrics import Metrics
+from .metrics import EphemeralMetrics, Metrics
 
 __all__ = [
     "Metrics",
+    "EphemeralMetrics",
     "single_metric",
     "MetricUnit",
     "MetricUnitError",
