@@ -208,19 +208,19 @@ def batch_processor(
         Lambda's Context
     record_handler: Callable
         Callable to process each record from the batch
-    processor: PartialSQSProcessor
+    processor: BasePartialProcessor
         Batch Processor to handle partial failure cases
 
     Examples
     --------
-    **Processes Lambda's event with PartialSQSProcessor**
+    **Processes Lambda's event with a BasePartialProcessor**
 
-        >>> from aws_lambda_powertools.utilities.batch import batch_processor, PartialSQSProcessor
+        >>> from aws_lambda_powertools.utilities.batch import batch_processor, BatchProcessor
         >>>
         >>> def record_handler(record):
         >>>     return record["body"]
         >>>
-        >>> @batch_processor(record_handler=record_handler, processor=PartialSQSProcessor())
+        >>> @batch_processor(record_handler=record_handler, processor=BatchProcessor())
         >>> def handler(event, context):
         >>>     return {"StatusCode": 200}
 
@@ -323,10 +323,10 @@ class BatchProcessor(BasePartialProcessor):
     @tracer.capture_method
     def record_handler(record: DynamoDBRecord):
         logger.info(record.dynamodb.new_image)
-        payload: dict = json.loads(record.dynamodb.new_image.get("item").s_value)
+        payload: dict = json.loads(record.dynamodb.new_image.get("item"))
         # alternatively:
-        # changes: Dict[str, dynamo_db_stream_event.AttributeValue] = record.dynamodb.new_image  # noqa: E800
-        # payload = change.get("Message").raw_event -> {"S": "<payload>"}
+        # changes: Dict[str, Any] = record.dynamodb.new_image  # noqa: E800
+        # payload = change.get("Message") -> "<payload>"
         ...
 
     @logger.inject_lambda_context
