@@ -5,11 +5,11 @@ Parameter retrieval and caching utility
 """
 
 from .appconfig import AppConfigProvider, get_app_config
-from .base import BaseProvider
+from .base import BaseProvider, clear_caches
 from .dynamodb import DynamoDBProvider
 from .exceptions import GetParameterError, TransformParameterError
 from .secrets import SecretsProvider, get_secret
-from .ssm import SSMProvider, get_parameter, get_parameters
+from .ssm import SSMProvider, get_parameter, get_parameters, get_parameters_by_name
 
 __all__ = [
     "AppConfigProvider",
@@ -22,5 +22,7 @@ __all__ = [
     "get_app_config",
     "get_parameter",
     "get_parameters",
+    "get_parameters_by_name",
     "get_secret",
+    "clear_caches",
 ]
